@@ -64,13 +64,13 @@ ExponentSet <- R6Class("ExponentSet",
       x <- listify(x)
 
       if (self$power == "n") {
-        len <- x[[1]]$length
-        if (len == 1) {
-         return(self$wrappedSets[[1]]$contains(unlist(rsapply(x, "elements", active = TRUE)),
-                                               all, bound))
-        } else {
-          return(setpower(self$wrappedSets[[1]], len)$contains(x, all, bound))
-        }
+        ret <- vapply(x, function(.x) {
+          if (testSet(.x)) {
+            self$wrappedSets[[1]]$contains(.x$elements, all = TRUE, bound = bound)
+          } else {
+            self$wrappedSets[[1]]$contains(.x, all = TRUE, bound = bound)
+          }
+        }, logical(1))
       } else {
         ret <- sapply(x, function(el) {
           if (!testSet(el)) {
