@@ -52,6 +52,23 @@ makeChecks(
   pos = environment()
 )
 
+#' @template assertions_class
+#' @templateVar class Multiset
+#' @export
+testMultiset <- function() {}
+#' @rdname testMultiset
+#' @export
+checkMultiset <- function() {}
+#' @rdname testMultiset
+#' @export
+assertMultiset <- function() {}
+makeChecks(
+  assertionName = "Multiset",
+  cond = inherits(object, "Multiset"),
+  errormsg = "This is not an R6 Multiset object",
+  pos = environment()
+)
+
 #' @template assertions_class
 #' @templateVar class FuzzySet
 #' @export
@@ -86,6 +103,23 @@ makeChecks(
   pos = environment()
 )
 
+#' @template assertions_class
+#' @templateVar class FuzzyMultiset
+#' @export
+testFuzzyMultiset <- function() {}
+#' @rdname testFuzzyMultiset
+#' @export
+checkFuzzyMultiset <- function() {}
+#' @rdname testFuzzyMultiset
+#' @export
+assertFuzzyMultiset <- function() {}
+makeChecks(
+  assertionName = "FuzzyMultiset",
+  cond = inherits(object, "FuzzyMultiset"),
+  errormsg = "This is not an R6 FuzzyMultiset object",
+  pos = environment()
+)
+
 #' @template assertions_class
 #' @templateVar class Interval
 #' @export
