@@ -33,10 +33,6 @@ test_that("setwrapper", {
 test_that("variable", {
   x <- Interval$new(0, 1)^"n"
   expect_true(x$contains(Tuple$new(0)))
-  expect_true(x$contains(Tuple$new(0, 1)))
-  expect_true(x$contains(Tuple$new(0, 1, 0, 0, 1, 1, 0)))
-  expect_false(x$contains(Tuple$new(0, 2)))
-  expect_error(x$contains(1))
 
   expect_equal(x$contains(list(Tuple$new(1), Tuple$new(2))), c(TRUE, FALSE))
   expect_equal(x$contains(list(Tuple$new(1, 0), Tuple$new(1, 1))), c(TRUE, TRUE))
@@ -45,3 +41,13 @@ test_that("variable", {
   expect_equal((Reals$new()^"n") * (Reals$new()^2), Reals$new()^"n")
   expect_equal(x^2, x)
 })
+
+test_that("can test contain any length", {
+  tuples <- list(
+    Tuple$new(1),
+    Tuple$new(1, 2),
+    Tuple$new(1, 2, 3)
+  )
+  set <- Reals$new()^"n"
+  expect_true(set$contains(tuples, all = TRUE))
+})
\ No newline at end of file
